import { TimeInterval } from '../interfaces/TimeInterval';
export class ChartDataService {
    static dataFormatter(type, dataPoint) {
        switch (type) {
            case 'date':
                return new Date(dataPoint);
            case 'number':
            case 'percent':
            case 'string':
            case 'currency':
            default:
                return dataPoint;
        }
    }
    static formatData(config, data) {
        const formatted = data.map(d => {
            return {
                y: ChartDataService.dataFormatter(config.yAxis.labelType, d.y),
                x: ChartDataService.dataFormatter(config.xAxis.labelType, d.x)
            };
        });
        return formatted;
    }
    static xFormatter(period, config, value) {
        return ChartDataService.axisLabelFormatter('xAxis', value, config, period);
    }
    static yFormatter(config, value) {
        return ChartDataService.axisLabelFormatter('yAxis', value, config);
    }
    static axisLabelFormatter(axis, value, config, period) {
        let currency = ChartDataService.DEFAULT_CURRENCY;
        let locale = ChartDataService.DEFAULT_LOCALE;
        let type;
        if (config[axis]) {
            type = config[axis].labelType;
            if (config[axis].formattingOptions) {
                locale = config[axis].formattingOptions.locale || ChartDataService.DEFAULT_LOCALE;
                currency = config[axis].formattingOptions.currency || ChartDataService.DEFAULT_CURRENCY;
            }
        }
        switch (type) {
            case 'currency':
                return new Intl.NumberFormat(locale, { style: 'currency', currency }).format(value);
            case 'percent':
                return `${value.toString()}%`;
            case 'number':
                return new Intl.NumberFormat(locale).format(value);
            case 'date':
                return ChartDataService.dateLabelFormatter(value, locale, period);
            case 'string':
            default:
                return value;
        }
    }
    static dateLabelFormatter(value, locale, period) {
        const formatParts = new Intl.DateTimeFormat(locale, { day: '2-digit', month: 'short', year: 'numeric', }).formatToParts(value);
        const day = formatParts.find(p => p.type === 'day').value.toString();
        const month = formatParts.find(p => p.type === 'month').value.toString();
        const year = formatParts.find(p => p.type === 'year').value.toString();
        switch (period) {
            case TimeInterval.Yearly:
                return year;
            case TimeInterval.Weekly:
            case TimeInterval.Daily:
                return `${day} ${month}`;
            default:
                return `${month} ${year}`;
        }
    }
}
ChartDataService.DEFAULT_CURRENCY = 'USD';
ChartDataService.DEFAULT_LOCALE = 'en-US';
